##################################################################################
# Caso 1                                                                         #
#                                                                                #
# Função para calcular tamanho da amostra se a variável escolhida for intervalar #
# e a população considerada infinita                                             #
##################################################################################
calcular_tamanho_amostra_intervalar_infinita <- function(nivel_confianca, sigma, erro) {
  # nivel_confianca: nível de confiança desejado (por exemplo, 0.95 para 95%)
  # sigma: desvio padrão da população
  # erro: margem de erro desejada
  z <- qnorm(1 - (1 - nivel_confianca) / 2)  # Valor crítico de Z para o nível de confiança
  n <- (z * sigma / erro)^2                  # Fórmula para calcular tamanho da amostra
  return(ceiling(n))                         # Arredondar para cima para garantir tamanho adequado
}

##################################################################################
# Caso 2                                                                         #
#                                                                                #
# Função para calcular tamanho da amostra se a variável escolhida for intervalar #
# e a população considerada finita                                               #
##################################################################################
calcular_tamanho_amostra_intervalar_finita <- function(N, nivel_confianca, sigma, erro) {
  # N: tamanho da população
  # nivel_confianca: nível de confiança desejado (por exemplo, 0.95 para 95%)
  # sigma: desvio padrão da população
  # erro: margem de erro desejada
  Z <- qnorm(1 - (1 - nivel_confianca) / 2)                      # Valor crítico de Z para o nível de confiança
  n <- (Z^2 * sigma^2 * N) / (erro^2 * (N - 1) + Z^2 * sigma^2)  # Fórmula para calcular tamanho da amostra
  return(ceiling(n))                                             # Arredondar para cima para garantir tamanho adequado
}

##################################################################################
# Caso 3                                                                         #
#                                                                                #
# Função para calcular tamanho da amostra se a variável escolhida for nominal ou #
# ordinal e a população considerada infinita                                     #
##################################################################################
calcular_tamanho_amostra_ord_nom_infinita <- function(nivel_confianca, p, erro) {
  # nivel_confianca: nível de confiança desejado (por exemplo, 0.95 para 95%)
  # p: proporção esperada da população (0,5 se não houver uma estimativa prévia)
  # erro: margem de erro desejada
  Z <- qnorm(1 - (1 - nivel_confianca) / 2)  # Valor crítico de Z para o nível de confiança
  n <- (Z^2 * p * (1 - p)) / erro^2          # Fórmula para calcular tamanho da amostra
  return(ceiling(n))                         # Arredondar para cima para garantir tamanho adequado
}

##################################################################################
# Caso 4                                                                         #
#                                                                                #
# Função para calcular tamanho da amostra se a variável escolhida for nominal ou #
# ordinal e a população considerada finita                                       #
##################################################################################
calcular_tamanho_amostra_ord_nom_finita <- function(N, nivel_confianca, p,  erro) {
  # N: tamanho da população
  # nivel_confianca: nível de confiança desejado (por exemplo, 0.95 para 95%)
  # p: proporção esperada da população (0,5 se não houver uma estimativa prévia)
  # erro: margem de erro desejada
  Z <- qnorm(1 - (1 - nivel_confianca) / 2)                              # Valor crítico de Z para o nível de confiança
  n <- (N * Z^2 * p * (1 - p)) / ((N - 1) * erro^2 + Z^2 * p * (1 - p))  # Fórmula para calcular tamanho da amostra
  return(ceiling(n))                                                     # Arredondar para cima para garantir tamanho adequado
}